@@ -1,8 +1,6 @@
 
 from uuid import uuid4
 
-from django.contrib.auth import authenticate, login
-from django.contrib.auth.models import User
 from django import forms
 from django.forms.extras.widgets import SelectDateWidget
 from django.utils.safestring import mark_safe
@@ -12,6 +10,26 @@ from mezzanine.conf import settings
 from mezzanine.core.models import Orderable
 
 
+class Html5Mixin(object):
+    """
+    Mixin for form classes. Adds HTML5 features to forms for client
+    side validation by the browser, like a "required" attribute and
+    "email" and "url" input types.
+    """
+
+    def __init__(self, *args, **kwargs):
+        super(Html5Mixin, self).__init__(*args, **kwargs)
+        if hasattr(self, "fields"):
+            for name, field in self.fields.items():
+                if settings.FORMS_USE_HTML5:
+                    if isinstance(field, forms.EmailField):
+                        self.fields[name].widget.input_type = "email"
+                    elif isinstance(field, forms.URLField):
+                        self.fields[name].widget.input_type = "url"
+                if field.required:
+                    self.fields[name].widget.attrs["required"] = ""
+
+
 class TinyMceWidget(forms.Textarea):
     """
     Setup the JS files and targetting CSS class for a textarea to
@@ -28,65 +46,6 @@ class TinyMceWidget(forms.Textarea):
         self.attrs["class"] = "mceEditor"
 
 
-class UserForm(forms.Form):
-    """
-    Fields for signup & login.
-    """
-    email = forms.EmailField(label=_("Email Address"))
-    password = forms.CharField(label=_("Password"),
-        widget=forms.PasswordInput(render_value=False))
-
-    def authenticate(self):
-        """
-        Validate email and password as well as setting the user for login.
-        """
-        self._user = authenticate(username=self.cleaned_data.get("email", ""),
-                               password=self.cleaned_data.get("password", ""))
-
-    def login(self, request):
-        """
-        Log the user in.
-        """
-        login(request, self._user)
-
-
-class SignupForm(UserForm):
-
-    def clean_email(self):
-        """
-        Ensure the email address is not already registered.
-        """
-        email = self.cleaned_data["email"]
-        try:
-            User.objects.get(username=email)
-        except User.DoesNotExist:
-            return email
-        raise forms.ValidationError(_("This email is already registered"))
-
-    def save(self):
-        """
-        Create the new user using their email address as their username.
-        """
-        User.objects.create_user(self.cleaned_data["email"],
-            self.cleaned_data["email"], self.cleaned_data["password"])
-        self.authenticate()
-
-
-class LoginForm(UserForm):
-
-    def clean(self):
-        """
-        Authenticate the email/password.
-        """
-        if "email" in self.cleaned_data and "password" in self.cleaned_data:
-            self.authenticate()
-            if self._user is None:
-                raise forms.ValidationError(_("Invalid email/password"))
-            elif not self._user.is_active:
-                raise forms.ValidationError(_("Your account is inactive"))
-        return self.cleaned_data
-
-
 class OrderWidget(forms.HiddenInput):
     """
     Add up and down arrows for ordering controls next to a hidden
